@@ -14,6 +14,8 @@
 #  See the License for the specific language governing permissions and
 #  limitations under the License.
 
+from __future__ import print_function
+from __future__ import absolute_import
 import pickle
 import random
 import threading
@@ -29,7 +31,7 @@ from calculate.core.server.core_interfaces import (CoreServiceInterface,
 from calculate.install.distr import Distributive
 from calculate.lib.cl_log import log
 from calculate.lib.utils.colortext import convert_console_to_xml
-from api_types import ReturnProgress
+from .api_types import ReturnProgress
 from calculate.lib.cl_lang import setLocalTranslate, getLazyLocalTranslate
 
 _ = lambda x: x
@@ -51,7 +53,7 @@ from calculate.core.server.api_types import (Field,
                                              GroupField, ViewInfo, ViewParams)
 from calculate.lib.cl_template import Template
 from calculate.lib.datavars import DataVars
-from loaded_methods import LoadedMethods
+from .loaded_methods import LoadedMethods
 
 
 class CommonMethods(MethodsInterface):
@@ -135,9 +137,9 @@ class CommonMethods(MethodsInterface):
                             i = filesApply.index(data[i_cfgname])
                             filesApply[i] = orig
                         except Exception as e:
-                            print str(e)
+                            print(str(e))
                 except Exception as e:
-                    print str(e)
+                    print(str(e))
                     self.printERROR(
                         _("Failed to copy {ffrom} to {fto}").format(
                             ffrom=data[i_cfgname], fto=orig))
@@ -149,7 +151,7 @@ class CommonMethods(MethodsInterface):
                         try:
                             filesApply.remove(data[i_cfgname])
                         except Exception as e:
-                            print str(e)
+                            print(str(e))
                 except OSError:
                     self.printERROR(
                         _("Failed to remove %s") % data[i_cfgname])
@@ -532,8 +534,8 @@ class Action(MethodsInterface):
         если у нет аргументов, то не передавать туда аргументы
         """
         args = []
-        arg_count = func_condition.func_code.co_argcount
-        for param_name in func_condition.func_code.co_varnames[:arg_count]:
+        arg_count = func_condition.__code__.co_argcount
+        for param_name in func_condition.__code__.co_varnames[:arg_count]:
             if param_name in ('Get', 'GetBool', 'Select', 'ZipVars'):
                 args.append(getattr(self.clVars, param_name))
             elif param_name == 'eachvar':
@@ -828,8 +830,8 @@ def catchExcept(*skipException):
         def __init__(self, f_static):
             f = f_static.__func__
             self.f = f
-            self.func_name = f.func_name
-            self.func_code = f.func_code
+            self.__name__ = f.__name__
+            self.__code__ = f.__code__
             self.__doc__ = f.__doc__
             self.__name__ = f.__name__
 
@@ -856,7 +858,7 @@ def catchExcept(*skipException):
 
                 if not any(isinstance(e, x)
                            for x in chain(skipException, (KeyboardInterrupt,))):
-                    print shortTraceback(*sys.exc_info())
+                    print(shortTraceback(*sys.exc_info()))
 
                 return view
 
@@ -868,8 +870,8 @@ def shortTraceback(e1, e2, e3):
     Return short traceback
     """
     frame = e3
-    for i in apply(traceback.format_exception, (e1, e2, e3)):
-        print i,
+    for i in traceback.format_exception(*(e1, e2, e3)):
+        print(i, end=' ')
     while frame.tb_next:
         frame = frame.tb_next
     module, part = os.path.split(frame.tb_frame.f_code.co_filename)
@@ -939,7 +941,7 @@ class CoreWsdl(CoreServiceInterface):
     def serv_get_methods(cls, client_type):
         curThread = threading.currentThread()
         certificate = curThread.client_cert
-        from cert_cmd import find_cert_id
+        from .cert_cmd import find_cert_id
 
         cert_id = find_cert_id(certificate, cls.data_path, cls.certbase)
 
@@ -971,7 +973,7 @@ class CoreWsdl(CoreServiceInterface):
     # return a list of methods for the console as list
     @staticmethod
     def return_conMethod():
-        from loaded_methods import LoadedMethods
+        from .loaded_methods import LoadedMethods
 
         results = []
         for item in LoadedMethods.conMethods:
@@ -984,7 +986,7 @@ class CoreWsdl(CoreServiceInterface):
     # return a list of methods for the GUI as list
     @staticmethod
     def return_guiMethod():
-        from loaded_methods import LoadedMethods
+        from .loaded_methods import LoadedMethods
 
         results = []
         dv = DataVars()
@@ -1064,7 +1066,7 @@ class CoreWsdl(CoreServiceInterface):
 
         def writeFile(self):
             """ write data in file """
-            from baseClass import Basic
+            from .baseClass import Basic
             from calculate.core.server.gen_pid import ProcessMode
 
             if not os.path.exists(Basic.pids):
@@ -1090,8 +1092,8 @@ class CoreWsdl(CoreServiceInterface):
                          }
                     pickle.dump(d, f)
             except (IOError, OSError) as e:
-                print str(e)
-                print _("Failed to write the PID file %s!") % pid_file
+                print(str(e))
+                print(_("Failed to write the PID file %s!") % pid_file)
 
         def setProgress(self, perc, short_message=None, long_message=None):
             try:
@@ -1148,7 +1150,7 @@ class CoreWsdl(CoreServiceInterface):
             while id in self.table_dict:
                 id = random.randint(1, self.Num)
 
-            from api_types import Table
+            from .api_types import Table
 
             table = Table(head=head, body=map(lambda x: map(str, x), body),
                           fields=fields,
@@ -1159,7 +1161,7 @@ class CoreWsdl(CoreServiceInterface):
 
         def addMessage(self, type='normal', message=None, id=None,
                        onlyShow='', default=None):
-            from api_types import Message
+            from .api_types import Message
 
             re_clean = re.compile('\[(?:\d+;)?\d+m')
             messageObj = Message(
@@ -1174,7 +1176,7 @@ class CoreWsdl(CoreServiceInterface):
             except BaseException as e:
                 if isinstance(e, KeyboardInterrupt):
                     raise
-                print _(("%s:" % type) + str(message))
+                print(_(("%s:" % type) + str(message)))
 
         def dropProgress(self):
             perc = self.getProgress()
@@ -1444,7 +1446,7 @@ class CoreWsdl(CoreServiceInterface):
                             for i in methods:
                                 results.append(i.strip())
                     except IndexError:
-                        print 'except IndexError in serv_view_cert_right'
+                        print('except IndexError in serv_view_cert_right')
                         continue
             results = uniq(results)
 
@@ -1559,7 +1561,7 @@ def create_symlink(data_path, old_data_path):
                 continue
             if os.path.isfile(link_path):
                 red = '\033[31m * \033[0m'
-                print red + link_path + _(' is a file, not a link!')
+                print(red + link_path + _(' is a file, not a link!'))
                 continue
             try:
                 if (os.path.islink(link_path) and
@@ -1567,9 +1569,9 @@ def create_symlink(data_path, old_data_path):
                     os.unlink(link_path)
                 os.symlink(core_wrapper, link_path)
                 fd.write(link_path + '\n')
-            except OSError, e:
-                print e.message
-            print _('Symlink %s created') % link_path
+            except OSError as e:
+                print(e.message)
+            print(_('Symlink %s created') % link_path)
 
     temp_text_file = ''
     for line in readLinesFile(symlinks_file):
@@ -1577,7 +1579,7 @@ def create_symlink(data_path, old_data_path):
         if cmdname not in meths.keys() or not line.startswith(path_to_link):
             if os.path.islink(line):
                 os.unlink(line)
-                print _('Symlink %s deleted') % line
+                print(_('Symlink %s deleted') % line)
         else:
             temp_text_file += line + '\n'
     fd = open(symlinks_file, 'w')
@@ -1604,7 +1606,7 @@ def initialization(cl_wsdl):
 
 # Creation of secret key of the client
 def new_key_req(key, cert_path, serv_host_name, port):
-    from create_cert import (generateRSAKey, makePKey, makeRequest,
+    from .create_cert import (generateRSAKey, makePKey, makeRequest,
                              passphrase_callback)
 
     rsa = generateRSAKey()
@@ -1709,7 +1711,7 @@ class WsdlMeta(type):
                                    invalidators=kwargs.get('invalidators', None)
                                    )
 
-        wrapper.func_name = kwargs['method_name']
+        wrapper.__name__ = kwargs['method_name']
         wrapper = staticmethod(wrapper)
         func = LoadedMethods.core_method(category=kwargs.get('category', None),
                                          title=kwargs['title'],
@@ -1811,7 +1813,7 @@ class WsdlMeta(type):
                 view = ViewInfo()
             return view
 
-        wrapper.func_name = "%s_view" % kwargs['method_name']
+        wrapper.__name__ = "%s_view" % kwargs['method_name']
         wrapper = staticmethod(wrapper)
         
         return catchExcept(kwargs.get("native_error", ()))(wrapper)
