@@ -15,6 +15,8 @@
 #  limitations under the License.
 
 import importlib
+import logging
+# logger = logging.getLogger(__name__)
 
 list_module = ["clean", "gen_pid",
                "sid_pid_file", "gen_sid", "func", "api_types"]
@@ -25,6 +27,7 @@ for module_name in list_module:
     imported_modules.append(importlib.import_module(
         '%s.%s' % (pack, module_name)).CoreWsdl)
 
+
 imported_modules.append(object)
 imported = tuple(imported_modules)
 
