@@ -193,6 +193,14 @@ class VariableClCorePkgSlotOpt(Variable):
             pkgs = list(pkgs)
             if pkgs:
                 return pkgs[0]["SLOTONLY"]
+        elif self.Get('cl_action') == 'config':
+            pkgs = getInstalledAtom(
+                "%s/%s" % (self.Get('cl_core_pkg_category'),
+                self.Get('cl_core_pkg_name')))
+            pkgs = list(pkgs)
+            if len(pkgs) == 1:
+                return pkgs[0]["SLOTONLY"]
+            return ""
         return "all"
 
     def choice(self):
@@ -205,12 +213,18 @@ class VariableClCorePkgSlotOpt(Variable):
             pkg = getInstalledAtom("%s/%s" % (self.Get('cl_core_pkg_category'),
                                             self.Get('cl_core_pkg_name')))
         pkg = list(sorted(pkg))
+        if self.Get('cl_action') == 'config':
+            allvalue = []
+        else:
+            allvalue = ["all"]
         if pkg:
-            return ["all"] + [x['SLOTONLY'] for x in pkg]
-        return ["all"]
+            return allvalue + [x['SLOTONLY'] for x in pkg]
+        return allvalue
 
 
     def check(self, value):
+        if self.Get('cl_action') == 'config' and value == "all":
+            raise VariableError(_("Please choose the slot"))
         if value != "all":
             pkg_name = self.Get('cl_core_pkg_name')
             if not value and pkg_name and pkg_name != "all":
